@@ -1118,8 +1118,6 @@ def _delete_event_rows(context, stack_id, limit):
     return retval
 
 
-@oslo_db_api.wrap_db_retry(max_retries=3, retry_on_deadlock=True,
-                           retry_interval=0.5, inc_retry_interval=True)
 def event_create(context, values):
     if 'stack_id' in values and cfg.CONF.max_events_per_stack:
         # only count events and purge on average
@@ -1149,7 +1147,7 @@ def software_config_create(context, values):
 
 def software_config_get(context, config_id):
     result = context.session.query(models.SoftwareConfig).get(config_id)
-    if (result is not None and context is not None and
+    if (result is not None and context is not None and not context.is_admin and
             result.tenant != context.tenant_id):
         result = None
 
@@ -1194,7 +1192,7 @@ def software_deployment_create(context, values):
 def software_deployment_get(context, deployment_id):
     result = context.session.query(
         models.SoftwareDeployment).get(deployment_id)
-    if (result is not None and context is not None and
+    if (result is not None and context is not None and not context.is_admin and
         context.tenant_id not in (result.tenant,
                                   result.stack_user_project_id)):
         result = None
@@ -1207,14 +1205,14 @@ def software_deployment_get(context, deployment_id):
 
 def software_deployment_get_all(context, server_id=None):
     sd = models.SoftwareDeployment
-    query = context.session.query(
-        sd
-    ).filter(sqlalchemy.or_(
-             sd.tenant == context.tenant_id,
-             sd.stack_user_project_id == context.tenant_id)
-             ).order_by(sd.created_at)
+    query = context.session.query(sd).order_by(sd.created_at)
+    if not context.is_admin:
+        query = query.filter(sqlalchemy.or_(
+            sd.tenant == context.tenant_id,
+            sd.stack_user_project_id == context.tenant_id))
     if server_id:
         query = query.filter_by(server_id=server_id)
+
     return query.all()
 
 
@@ -1548,8 +1546,6 @@ def sync_point_get(context, entity_id, traversal_id, is_update):
     )
 
 
-@oslo_db_api.wrap_db_retry(max_retries=3, retry_on_deadlock=True,
-                           retry_interval=0.5, inc_retry_interval=True)
 def sync_point_update_input_data(context, entity_id,
                                  traversal_id, is_update, atomic_key,
                                  input_data):
